<div class="lang">
    <ul>
        {items}
        <li {active}>
            <a href="{link}">
                <span>{name}</span>
                <img alt="{name}" src="/assets/img/{short_name}.png" />
            </a>
        </li>
        {/items}
    </ul>
</div>